@@ -1,3 +1,4 @@
+from drf_spectacular.utils import extend_schema_field
 from rest_framework import serializers
 
 from ..models import CustomUser, RegistrationSource, UserRegistrationSource
@@ -9,6 +10,7 @@ class UserSerializer(serializers.ModelSerializer):
     full_name = serializers.ReadOnlyField()
     initials = serializers.ReadOnlyField()
     display_username = serializers.ReadOnlyField()
+    avatar = serializers.SerializerMethodField()
 
     class Meta:
         model = CustomUser
@@ -40,6 +42,16 @@ class UserSerializer(serializers.ModelSerializer):
             "unanswered_messages_count",
         ]
 
+    @extend_schema_field(serializers.URLField(allow_null=True))
+    def get_avatar(self, obj):
+        """Return full URL for avatar or None."""
+        if obj.avatar:
+            request = self.context.get('request')
+            if request is not None:
+                return request.build_absolute_uri(obj.avatar.url)
+            return obj.avatar.url
+        return None
+
 
 
 class UserProfileUpdateSerializer(serializers.ModelSerializer):
