@@ -73,7 +73,7 @@ class UserProfileUpdateView(generics.UpdateAPIView):
         self.perform_update(serializer)
 
         # Return full user data
-        user_serializer = UserSerializer(instance)
+        user_serializer = UserSerializer(instance, context={'request': request})
         return Response(user_serializer.data, status=status.HTTP_200_OK)
 
 
@@ -161,5 +161,5 @@ def upload_avatar(request):
     serializer.save()
 
     # Return updated user data
-    user_serializer = UserSerializer(user)
+    user_serializer = UserSerializer(user, context={'request': request})
     return Response(user_serializer.data, status=status.HTTP_200_OK)
