@@ -4,17 +4,22 @@ Django Agents - Custom model managers.
 
 from .execution import AgentExecutionManager, WorkflowExecutionManager
 from .registry import AgentDefinitionManager, AgentTemplateManager
-from .toolsets import ToolExecutionManager, ApprovalLogManager, ToolsetConfigurationManager, ToolPermissionManager
+from .toolsets import (
+    ApprovalLogManager,
+    ToolExecutionManager,
+    ToolPermissionManager,
+    ToolsetConfigurationManager,
+)
 
 __all__ = [
     # Execution managers
     'AgentExecutionManager',
     'WorkflowExecutionManager',
-    
+
     # Registry managers
     'AgentDefinitionManager',
     'AgentTemplateManager',
-    
+
     # Toolsets managers
     'ToolExecutionManager',
     'ApprovalLogManager',
