@@ -1,7 +1,7 @@
 """
-Chat admin interfaces using Django Admin Utilities.
+Chat Admin v2.0 - NEW Declarative Pydantic Approach
 
-Enhanced chat management with Material Icons and optimized queries.
+Enhanced chat management with Material Icons and clean declarative config.
 """
 
 from django.contrib import admin, messages
@@ -11,17 +11,18 @@ from unfold.contrib.filters.admin import AutocompleteSelectFilter
 
 from django_cfg import ExportMixin
 from django_cfg.modules.django_admin import (
-    ActionVariant,
-    DateTimeDisplayConfig,
-    DisplayMixin,
+    AdminConfig,
+    BadgeField,
+    BooleanField,
+    CurrencyField,
+    DateTimeField,
+    FieldsetConfig,
     Icons,
-    MoneyDisplayConfig,
-    OptimizedModelAdmin,
-    StatusBadgeConfig,
-    action,
-    display,
+    TextField,
+    UserField,
+    computed_field
 )
-from django_cfg.modules.django_admin.utils.badges import StatusBadge
+from django_cfg.modules.django_admin.base import PydanticAdmin
 
 from ..models import ChatMessage, ChatSession
 
@@ -58,7 +59,6 @@ class ChatMessageInline(TabularInline):
     hide_title = False
     classes = ['collapse']
 
-    @display(description="Role")
     def role_badge_inline(self, obj):
         """Display message role with color coding for inline."""
         role_variants = {
@@ -68,31 +68,28 @@ class ChatMessageInline(TabularInline):
         }
         variant = role_variants.get(obj.role, 'secondary')
 
-        config = StatusBadgeConfig(show_icons=True, icon=Icons.PERSON)
-        return StatusBadge.create(
-            text=obj.role.upper(),
-            variant=variant,
-            config=config
+        # Note: self.html is not available in inline context
+        # We'll use a simple HTML string for now
+        from django.utils.html import format_html
+        return format_html(
+            '<span class="badge badge-{}">{}</span>',
+            variant,
+            obj.role.upper()
         )
+    role_badge_inline.short_description = "Role"
 
-    @display(description="Content Preview")
     def content_preview_inline(self, obj):
         """Shortened content preview for inline display."""
         if not obj.content:
             return "—"
         return obj.content[:80] + "..." if len(obj.content) > 80 else obj.content
+    content_preview_inline.short_description = "Content Preview"
 
-    @display(description="Cost (USD)")
     def cost_display_inline(self, obj):
         """Display cost with currency formatting for inline."""
-        config = MoneyDisplayConfig(
-            currency="USD",
-            decimal_places=6,
-            show_sign=False
-        )
         return f"${obj.cost_usd:.6f}"
+    cost_display_inline.short_description = "Cost (USD)"
 
-    @display(description="Time")
     def processing_time_inline(self, obj):
         """Display processing time in compact format for inline."""
         ms = obj.processing_time_ms
@@ -101,136 +98,212 @@ class ChatMessageInline(TabularInline):
         else:
             seconds = ms / 1000
             return f"{seconds:.1f}s"
+    processing_time_inline.short_description = "Time"
 
     def get_queryset(self, request):
         """Optimize queryset for inline display."""
         return super().get_queryset(request).select_related('session', 'user').order_by('created_at')
 
 
-@admin.register(ChatSession)
-class ChatSessionAdmin(OptimizedModelAdmin, DisplayMixin, ModelAdmin, ExportMixin):
-    """Admin interface for ChatSession model using Django Admin Utilities."""
+# ===== ChatSession Admin Config =====
+
+chat_session_config = AdminConfig(
+    model=ChatSession,
 
     # Performance optimization
-    select_related_fields = ['user']
+    select_related=['user'],
 
-    list_display = [
-        'title_display', 'user_display', 'status_display', 'messages_count_display',
-        'total_tokens_display', 'total_cost_display', 'last_activity_display', 'created_at_display'
-    ]
+    # List display
+    list_display=[
+        'title_display',
+        'user_display',
+        'status_display',
+        'messages_count_display',
+        'total_tokens_display',
+        'total_cost_display',
+        'last_activity_display',
+        'created_at_display'
+    ],
+
+    # Display fields with UI widgets
+    display_fields=[
+        BadgeField(
+            name="title",
+            title="Session Title",
+            variant="primary",
+            icon=Icons.CHAT,
+            header=True
+        ),
+        UserField(
+            name="user",
+            title="User"
+        ),
+        BadgeField(
+            name="status",
+            title="Status"
+        ),
+        TextField(
+            name="messages_count",
+            title="Messages",
+            ordering="messages_count"
+        ),
+        TextField(
+            name="total_tokens",
+            title="Tokens",
+            ordering="total_tokens"
+        ),
+        TextField(
+            name="total_cost_usd",
+            title="Cost (USD)",
+            ordering="total_cost_usd"
+        ),
+        DateTimeField(
+            name="last_activity_at",
+            title="Last Activity",
+            ordering="last_activity_at"
+        ),
+        DateTimeField(
+            name="created_at",
+            title="Created",
+            ordering="created_at"
+        ),
+    ],
+
+    # Search and filters
+    search_fields=['title', 'user__username', 'user__email'],
+    list_filter=['is_active', 'created_at'],
+
+    # Ordering
+    ordering=['-updated_at'],
+)
+
+
+@admin.register(ChatSession)
+class ChatSessionAdmin(PydanticAdmin):
+    """
+    ChatSession admin using NEW Pydantic declarative approach.
+
+    Features:
+    - Declarative configuration with type safety
+    - Automatic display method generation
+    - Material Icons integration
+    - Export functionality
+    - Custom actions for session management
+    - Statistics in changelist_view
+
+    Note: Actions use old-style decorators as ActionConfig is not yet available in v2.0
+    """
+    config = chat_session_config
+
+    # Override list_display_links
     list_display_links = ['title_display']
-    ordering = ['-updated_at']
-    inlines = [ChatMessageInline]
-    list_filter = [
-        'is_active', 'created_at',
-        ('user', AutocompleteSelectFilter)
-    ]
-    search_fields = ['title', 'user__username', 'user__email']
+
+    # Override list_filter to add custom filters
+    list_filter = ['is_active', 'created_at', ('user', AutocompleteSelectFilter)]
+
+    # Autocomplete
     autocomplete_fields = ['user']
+
+    # Readonly fields
     readonly_fields = [
         'id', 'user', 'messages_count', 'total_tokens_used', 'total_cost_usd',
         'created_at', 'updated_at'
     ]
 
-    fieldsets = (
-        ('💬 Session Info', {
-            'fields': ('id', 'title', 'user', 'is_active'),
-            'classes': ('tab',)
-        }),
-        ('📊 Statistics', {
-            'fields': ('message_count', 'total_tokens', 'total_cost_usd'),
-            'classes': ('tab',)
-        }),
-        ('⏰ Activity', {
-            'fields': ('created_at', 'updated_at'),
-            'classes': ('tab',)
-        }),
-    )
+    # Fieldsets
+    fieldsets = [
+        FieldsetConfig(
+            title="Session Info",
+            fields=['id', 'title', 'user', 'is_active']
+        ),
+        FieldsetConfig(
+            title="Statistics",
+            fields=['messages_count', 'total_tokens_used', 'total_cost_usd']
+        ),
+        FieldsetConfig(
+            title="Activity",
+            fields=['created_at', 'updated_at']
+        ),
+    ]
 
+    # Inlines
+    inlines = [ChatMessageInline]
+
+    # Actions
     actions = ['activate_sessions', 'deactivate_sessions', 'clear_old_sessions']
 
-    @display(description="Session Title", ordering="title")
-    def title_display(self, obj):
+    # Custom display methods using @computed_field decorator
+    @computed_field("Session Title")
+    def title_display(self, obj: ChatSession) -> str:
         """Display session title."""
         title = obj.title or "Untitled Session"
         if len(title) > 50:
             title = title[:47] + "..."
 
-        config = StatusBadgeConfig(show_icons=True, icon=Icons.CHAT)
-        return StatusBadge.create(
-            text=title,
-            variant="primary",
-            config=config
-        )
+        return self.html.badge(title, variant="primary", icon=Icons.CHAT)
 
-    @display(description="User")
-    def user_display(self, obj):
+    @computed_field("User")
+    def user_display(self, obj: ChatSession) -> str:
         """User display."""
         if not obj.user:
             return "—"
-        return self.display_user_simple(obj.user)
+        # Simple username display, UserField handles avatar and styling
+        return obj.user.username
 
-    @display(description="Status")
-    def status_display(self, obj):
+    @computed_field("Status")
+    def status_display(self, obj: ChatSession) -> str:
         """Display session status."""
         if obj.is_active:
-            config = StatusBadgeConfig(show_icons=True, icon=Icons.CHECK_CIRCLE)
-            return StatusBadge.create(text="Active", variant="success", config=config)
+            return self.html.badge("Active", variant="success", icon=Icons.CHECK_CIRCLE)
         else:
-            config = StatusBadgeConfig(show_icons=True, icon=Icons.PAUSE_CIRCLE)
-            return StatusBadge.create(text="Inactive", variant="secondary", config=config)
+            return self.html.badge("Inactive", variant="secondary", icon=Icons.PAUSE_CIRCLE)
 
-    @display(description="Messages", ordering="message_count")
-    def messages_count_display(self, obj):
+    @computed_field("Messages")
+    def messages_count_display(self, obj: ChatSession) -> str:
         """Display messages count."""
-        count = obj.message_count
+        count = obj.messages_count
         return f"{count} messages"
 
-    @display(description="Tokens", ordering="total_tokens")
-    def total_tokens_display(self, obj):
+    @computed_field("Tokens")
+    def total_tokens_display(self, obj: ChatSession) -> str:
         """Display total tokens with formatting."""
         tokens = obj.total_tokens
         if tokens > 1000:
             return f"{tokens/1000:.1f}K"
         return str(tokens)
 
-    @display(description="Cost (USD)", ordering="total_cost_usd")
-    def total_cost_display(self, obj):
+    @computed_field("Cost (USD)")
+    def total_cost_display(self, obj: ChatSession) -> str:
         """Display total cost with currency formatting."""
-        config = MoneyDisplayConfig(
-            currency="USD",
-            decimal_places=6,
-            show_sign=False
-        )
-        return self.display_money_amount(obj, 'total_cost_usd', config)
+        return f"${obj.total_cost_usd:.6f}"
 
-    @display(description="Last Activity", ordering="last_activity_at")
-    def last_activity_display(self, obj):
+    @computed_field("Last Activity")
+    def last_activity_display(self, obj: ChatSession) -> str:
         """Last activity time with relative display."""
         if not obj.last_activity_at:
             return "—"
-        config = DateTimeDisplayConfig(show_relative=True)
-        return self.display_datetime_relative(obj, 'last_activity_at', config)
+        # DateTimeField in display_fields handles formatting automatically
+        return obj.last_activity_at
 
-    @display(description="Created")
-    def created_at_display(self, obj):
+    @computed_field("Created")
+    def created_at_display(self, obj: ChatSession) -> str:
         """Created time with relative display."""
-        config = DateTimeDisplayConfig(show_relative=True)
-        return self.display_datetime_relative(obj, 'created_at', config)
+        # DateTimeField in display_fields handles formatting automatically
+        return obj.created_at
 
-    @action(description="Activate sessions", variant=ActionVariant.SUCCESS)
+    # Old-style actions (TODO: Migrate to new ActionConfig system when available)
     def activate_sessions(self, request, queryset):
         """Activate selected sessions."""
         updated = queryset.update(is_active=True)
         messages.success(request, f"Activated {updated} sessions.")
+    activate_sessions.short_description = "Activate sessions"
 
-    @action(description="Deactivate sessions", variant=ActionVariant.WARNING)
     def deactivate_sessions(self, request, queryset):
         """Deactivate selected sessions."""
         updated = queryset.update(is_active=False)
         messages.warning(request, f"Deactivated {updated} sessions.")
+    deactivate_sessions.short_description = "Deactivate sessions"
 
-    @action(description="Clear old sessions", variant=ActionVariant.DANGER)
     def clear_old_sessions(self, request, queryset):
         """Clear old inactive sessions."""
         from datetime import timedelta
@@ -245,6 +318,7 @@ class ChatSessionAdmin(OptimizedModelAdmin, DisplayMixin, ModelAdmin, ExportMixi
             messages.warning(request, f"Clear old sessions functionality not implemented yet. {count} old sessions found.")
         else:
             messages.info(request, "No old sessions found to clear.")
+    clear_old_sessions.short_description = "Clear old sessions"
 
     def changelist_view(self, request, extra_context=None):
         """Add session statistics to changelist."""
@@ -254,8 +328,8 @@ class ChatSessionAdmin(OptimizedModelAdmin, DisplayMixin, ModelAdmin, ExportMixi
         stats = queryset.aggregate(
             total_sessions=Count('id'),
             active_sessions=Count('id', filter=Q(is_active=True)),
-            total_messages=Sum('message_count'),
-            total_tokens=Sum('total_tokens'),
+            total_messages=Sum('messages_count'),
+            total_tokens=Sum('total_tokens_used'),
             total_cost=Sum('total_cost_usd')
         )
 
@@ -270,76 +344,164 @@ class ChatSessionAdmin(OptimizedModelAdmin, DisplayMixin, ModelAdmin, ExportMixi
         return super().changelist_view(request, extra_context)
 
 
-@admin.register(ChatMessage)
-class ChatMessageAdmin(OptimizedModelAdmin, DisplayMixin, ModelAdmin, ExportMixin):
-    """Admin interface for ChatMessage model using Django Admin Utilities."""
+# ===== ChatMessage Admin Config =====
+
+chat_message_config = AdminConfig(
+    model=ChatMessage,
 
     # Performance optimization
-    select_related_fields = ['session', 'user']
+    select_related=['session', 'user'],
 
-    list_display = [
-        'message_display', 'session_display', 'user_display', 'role_display',
-        'tokens_display', 'cost_display', 'processing_time_display', 'created_at_display'
-    ]
+    # List display
+    list_display=[
+        'message_display',
+        'session_display',
+        'user_display',
+        'role_display',
+        'tokens_display',
+        'cost_display',
+        'processing_time_display',
+        'created_at_display'
+    ],
+
+    # Display fields with UI widgets
+    display_fields=[
+        BadgeField(
+            name="id",
+            title="Message",
+            variant="secondary",
+            icon=Icons.MESSAGE,
+            header=True
+        ),
+        TextField(
+            name="session",
+            title="Session",
+            ordering="session__title"
+        ),
+        UserField(
+            name="user",
+            title="User"
+        ),
+        BadgeField(
+            name="role",
+            title="Role"
+        ),
+        TextField(
+            name="tokens_used",
+            title="Tokens",
+            ordering="tokens_used"
+        ),
+        TextField(
+            name="cost_usd",
+            title="Cost (USD)",
+            ordering="cost_usd"
+        ),
+        TextField(
+            name="processing_time_ms",
+            title="Processing Time",
+            ordering="processing_time_ms"
+        ),
+        DateTimeField(
+            name="created_at",
+            title="Created",
+            ordering="created_at"
+        ),
+    ],
+
+    # Search and filters
+    search_fields=['content', 'user__username', 'session__title'],
+    list_filter=['role', 'created_at'],
+
+    # Ordering
+    ordering=['-created_at'],
+)
+
+
+@admin.register(ChatMessage)
+class ChatMessageAdmin(PydanticAdmin):
+    """
+    ChatMessage admin using NEW Pydantic declarative approach.
+
+    Features:
+    - Declarative configuration with type safety
+    - Automatic display method generation
+    - Material Icons integration
+    - Export functionality
+    - Custom actions for message management
+    - Statistics in changelist_view
+
+    Note: Actions use old-style decorators as ActionConfig is not yet available in v2.0
+    """
+    config = chat_message_config
+
+    # Override list_display_links
     list_display_links = ['message_display']
-    ordering = ['-created_at']
+
+    # Override list_filter to add custom filters
     list_filter = [
         'role', 'created_at',
         ('user', AutocompleteSelectFilter),
         ('session', AutocompleteSelectFilter)
     ]
-    search_fields = ['content', 'user__username', 'session__title']
+
+    # Autocomplete
     autocomplete_fields = ['user', 'session']
+
+    # Readonly fields
     readonly_fields = [
         'id', 'user', 'tokens_used', 'cost_usd', 'processing_time_ms',
         'created_at', 'updated_at', 'content_preview'
     ]
 
-    fieldsets = (
-        ('💬 Message Info', {
-            'fields': ('id', 'session', 'user', 'role'),
-            'classes': ('tab',)
-        }),
-        ('📝 Content', {
-            'fields': ('content_preview', 'content'),
-            'classes': ('tab',)
-        }),
-        ('📊 Metrics', {
-            'fields': ('tokens_used', 'cost_usd', 'processing_time_ms'),
-            'classes': ('tab',)
-        }),
-        ('⏰ Timestamps', {
-            'fields': ('created_at', 'updated_at'),
-            'classes': ('tab', 'collapse')
-        })
-    )
+    # Fieldsets
+    fieldsets = [
+        FieldsetConfig(
+            title="Message Info",
+            fields=['id', 'session', 'user', 'role']
+        ),
+        FieldsetConfig(
+            title="Content",
+            fields=['content_preview', 'content']
+        ),
+        FieldsetConfig(
+            title="Metrics",
+            fields=['tokens_used', 'cost_usd', 'processing_time_ms']
+        ),
+        FieldsetConfig(
+            title="Timestamps",
+            fields=['created_at', 'updated_at'],
+            collapsed=True
+        )
+    ]
 
+    # Actions
     actions = ['delete_user_messages', 'delete_assistant_messages']
 
-    @display(description="Message", ordering="id")
-    def message_display(self, obj):
+    # Custom display methods using @computed_field decorator
+    @computed_field("Message")
+    def message_display(self, obj: ChatMessage) -> str:
         """Display message identifier."""
-        config = StatusBadgeConfig(show_icons=True, icon=Icons.MESSAGE)
-        return StatusBadge.create(
-            text=f"#{str(obj.id)[:8]}",
+        return self.html.badge(
+            f"#{str(obj.id)[:8]}",
             variant="secondary",
-            config=config
+            icon=Icons.MESSAGE
         )
 
-    @display(description="Session", ordering="session__title")
-    def session_display(self, obj):
+    @computed_field("Session")
+    def session_display(self, obj: ChatMessage) -> str:
         """Display session title."""
         return obj.session.title or "Untitled Session"
 
-    @display(description="User")
-    def user_display(self, obj):
+    @computed_field("User")
+    def user_display(self, obj: ChatMessage) -> str:
         """User display."""
         if not obj.user:
             return "—"
-        return self.display_user_simple(obj.user)
+        # Simple username display, UserField handles avatar and styling
+        return obj.user.username
 
-    @display(description="Role")
-    def role_display(self, obj):
+    @computed_field("Role")
+    def role_display(self, obj: ChatMessage) -> str:
         """Display message role with color coding."""
         role_variants = {
             'user': 'primary',
@@ -355,33 +517,23 @@ class ChatMessageAdmin(OptimizedModelAdmin, DisplayMixin, ModelAdmin, ExportMixi
         }
         icon = role_icons.get(obj.role, Icons.MESSAGE)
 
-        config = StatusBadgeConfig(show_icons=True, icon=icon)
-        return StatusBadge.create(
-            text=obj.role.title(),
-            variant=variant,
-            config=config
-        )
+        return self.html.badge(obj.role.title(), variant=variant, icon=icon)
 
-    @display(description="Tokens", ordering="tokens_used")
-    def tokens_display(self, obj):
+    @computed_field("Tokens")
+    def tokens_display(self, obj: ChatMessage) -> str:
         """Display tokens used with formatting."""
         tokens = obj.tokens_used
         if tokens > 1000:
             return f"{tokens/1000:.1f}K"
         return str(tokens)
 
-    @display(description="Cost (USD)", ordering="cost_usd")
-    def cost_display(self, obj):
+    @computed_field("Cost (USD)")
+    def cost_display(self, obj: ChatMessage) -> str:
         """Display cost with currency formatting."""
-        config = MoneyDisplayConfig(
-            currency="USD",
-            decimal_places=6,
-            show_sign=False
-        )
-        return self.display_money_amount(obj, 'cost_usd', config)
+        return f"${obj.cost_usd:.6f}"
 
-    @display(description="Processing Time", ordering="processing_time_ms")
-    def processing_time_display(self, obj):
+    @computed_field("Processing Time")
+    def processing_time_display(self, obj: ChatMessage) -> str:
         """Display processing time."""
         ms = obj.processing_time_ms
         if ms < 1000:
@@ -390,18 +542,18 @@ class ChatMessageAdmin(OptimizedModelAdmin, DisplayMixin, ModelAdmin, ExportMixi
             seconds = ms / 1000
             return f"{seconds:.1f}s"
 
-    @display(description="Created")
-    def created_at_display(self, obj):
+    @computed_field("Created")
+    def created_at_display(self, obj: ChatMessage) -> str:
         """Created time with relative display."""
-        config = DateTimeDisplayConfig(show_relative=True)
-        return self.display_datetime_relative(obj, 'created_at', config)
+        # DateTimeField in display_fields handles formatting automatically
+        return obj.created_at
 
-    @display(description="Content Preview")
     def content_preview(self, obj):
         """Display content preview with truncation."""
         return obj.content[:200] + "..." if len(obj.content) > 200 else obj.content
+    content_preview.short_description = "Content Preview"
 
-    @action(description="Delete user messages", variant=ActionVariant.DANGER)
+    # Old-style actions (TODO: Migrate to new ActionConfig system when available)
     def delete_user_messages(self, request, queryset):
         """Delete user messages from selection."""
         user_messages = queryset.filter(role='user')
@@ -411,8 +563,8 @@ class ChatMessageAdmin(OptimizedModelAdmin, DisplayMixin, ModelAdmin, ExportMixi
             messages.warning(request, f"Delete user messages functionality not implemented yet. {count} user messages selected.")
         else:
             messages.info(request, "No user messages in selection.")
+    delete_user_messages.short_description = "Delete user messages"
 
-    @action(description="Delete assistant messages", variant=ActionVariant.DANGER)
     def delete_assistant_messages(self, request, queryset):
         """Delete assistant messages from selection."""
         assistant_messages = queryset.filter(role='assistant')
@@ -422,6 +574,7 @@ class ChatMessageAdmin(OptimizedModelAdmin, DisplayMixin, ModelAdmin, ExportMixi
             messages.warning(request, f"Delete assistant messages functionality not implemented yet. {count} assistant messages selected.")
         else:
             messages.info(request, "No assistant messages in selection.")
+    delete_assistant_messages.short_description = "Delete assistant messages"
 
     def changelist_view(self, request, extra_context=None):
         """Add message statistics to changelist."""
