@@ -6,7 +6,7 @@ import logging
 
 from django.utils.decorators import method_decorator
 from django_ratelimit.decorators import ratelimit
-from drf_spectacular.utils import extend_schema
+from drf_spectacular.utils import OpenApiResponse, extend_schema
 from rest_framework import parsers, status
 from rest_framework.decorators import action
 from rest_framework.permissions import IsAdminUser, IsAuthenticated
@@ -85,9 +85,9 @@ class DocumentArchiveViewSet(BaseKnowledgeViewSet):
         },
         responses={
             201: ArchiveProcessingResultSerializer,
-            400: "Validation errors",
-            413: "File too large",
-            429: "Rate limit exceeded"
+            400: OpenApiResponse(description="Validation errors"),
+            413: OpenApiResponse(description="File too large"),
+            429: OpenApiResponse(description="Rate limit exceeded")
         }
     )
     @method_decorator(ratelimit(key='user', rate='5/hour', method='POST'))
