@@ -149,13 +149,23 @@ class ChatViewSet(BaseKnowledgeViewSet):
 
         service = self.get_service()
 
-        # Create session if not provided
+        # Create session if not provided or doesn't exist
         session_id = serializer.validated_data.get('session_id')
         if not session_id:
+            # No session_id provided - create new session
             session = service.create_session()
             session_id = str(session.id)
         else:
+            # Verify session exists and belongs to user, or create new one
             session_id = str(session_id)
+            if not ChatSession.objects.filter(
+                id=session_id,
+                user=request.user,
+                is_active=True
+            ).exists():
+                # Session doesn't exist or doesn't belong to user - create new one
+                session = service.create_session()
+                session_id = str(session.id)
 
         # Process query
         result = service.process_query(
