@@ -4,7 +4,8 @@ Document management API views.
 
 from django.utils.decorators import method_decorator
 from django_ratelimit.decorators import ratelimit
-from drf_spectacular.utils import OpenApiExample, OpenApiParameter, extend_schema
+from drf_spectacular.utils import OpenApiExample, OpenApiParameter, OpenApiResponse, extend_schema
+from drf_spectacular.types import OpenApiTypes
 from rest_framework import status
 from rest_framework.decorators import action
 from rest_framework.permissions import IsAdminUser, IsAuthenticated
@@ -44,9 +45,9 @@ class DocumentViewSet(BaseKnowledgeViewSet):
         description="Upload and process a new knowledge document",
         responses={
             201: DocumentSerializer,
-            400: "Validation errors",
-            413: "File too large",
-            429: "Rate limit exceeded"
+            400: OpenApiResponse(description="Validation errors"),
+            413: OpenApiResponse(description="File too large"),
+            429: OpenApiResponse(description="Rate limit exceeded")
         },
         examples=[
             OpenApiExample(
@@ -109,7 +110,7 @@ class DocumentViewSet(BaseKnowledgeViewSet):
         summary="Get document details",
         responses={
             200: DocumentSerializer,
-            404: "Document not found"
+            404: OpenApiResponse(description="Document not found")
         }
     )
     def retrieve(self, request, *args, **kwargs):
@@ -119,8 +120,8 @@ class DocumentViewSet(BaseKnowledgeViewSet):
     @extend_schema(
         summary="Delete document",
         responses={
-            204: "Document deleted successfully",
-            404: "Document not found"
+            204: OpenApiResponse(description="Document deleted successfully"),
+            404: OpenApiResponse(description="Document not found")
         }
     )
     def destroy(self, request, *args, **kwargs):
