@@ -3,7 +3,7 @@ Public API views for client access without authentication.
 """
 
 from django.db import models
-from drf_spectacular.utils import OpenApiParameter, extend_schema
+from drf_spectacular.utils import OpenApiParameter, OpenApiResponse, extend_schema
 from rest_framework import viewsets
 from rest_framework.permissions import AllowAny
 from rest_framework.response import Response
@@ -91,7 +91,7 @@ class PublicDocumentViewSet(viewsets.ReadOnlyModelViewSet):
         description="Get document details by ID (public access)",
         responses={
             200: PublicDocumentSerializer,
-            404: "Document not found"
+            404: OpenApiResponse(description="Document not found")
         }
     )
     def retrieve(self, request, *args, **kwargs):
@@ -121,7 +121,7 @@ class PublicCategoryViewSet(viewsets.ReadOnlyModelViewSet):
         description="Get category details by ID (public access)",
         responses={
             200: PublicCategorySerializer,
-            404: "Category not found"
+            404: OpenApiResponse(description="Category not found")
         }
     )
     def retrieve(self, request, *args, **kwargs):
