@@ -313,9 +313,13 @@ class StartupDisplayManager(BaseDisplayManager):
             payment_table.add_column("Value", style="white")
 
             payment_table.add_row("Enabled", f"[green]{self.config.payments.enabled}[/green]")
-            middleware_enabled = self.config.payments.middleware_enabled
-            color = 'green' if middleware_enabled else 'red'
-            payment_table.add_row("Middleware", f"[{color}]{middleware_enabled}[/{color}]")
+
+            # Show active providers (v2.0)
+            active_providers = self.config.payments.active_providers
+            if active_providers:
+                payment_table.add_row("Providers", f"[green]{', '.join(active_providers)}[/green]")
+            else:
+                payment_table.add_row("Providers", "[yellow]None configured[/yellow]")
 
             config_panels.append(self.create_panel(
                 payment_table,
