@@ -46,9 +46,7 @@ from .ngrok.config import NgrokConfig
 from .ngrok.tunnel import NgrokTunnelConfig
 
 # Payments
-from .payments.config import PaymentsConfig
-from .payments.providers.base import BaseProviderConfig
-from .payments.providers.nowpayments import NowPaymentsProviderConfig
+from .payments.config import PaymentsConfig, NowPaymentsConfig
 from .services.base import ServiceConfig
 
 # Services
@@ -90,6 +88,5 @@ __all__ = [
     "NgrokTunnelConfig",
     # Payments
     "PaymentsConfig",
-    "BaseProviderConfig",
-    "NowPaymentsProviderConfig",
+    "NowPaymentsConfig",
 ]
