@@ -2,7 +2,8 @@
 Redoc UI settings for DRF Spectacular.
 """
 
-from typing import Dict, Any
+from typing import Any, Dict
+
 from pydantic import BaseModel, Field
 
 
