@@ -4,13 +4,13 @@ Django-specific configuration models for django_cfg.
 Django integrations and extensions.
 """
 
-from .environment import EnvironmentConfig
 from .constance import ConstanceConfig, ConstanceField
-from .revolution import RevolutionConfig
+from .environment import EnvironmentConfig
+from .openapi import OpenAPIClientConfig
 
 __all__ = [
     "EnvironmentConfig",
     "ConstanceConfig",
     "ConstanceField",
-    "RevolutionConfig",
+    "OpenAPIClientConfig",
 ]
