@@ -157,50 +157,6 @@ class MoneyDisplay:
         return html
 
 
-class StatusDisplay:
-    """Status display utilities."""
-
-    @classmethod
-    def auto(cls, status: str) -> SafeString:
-        """Auto status display with color mapping."""
-        if not status:
-            return format_html('<span class="text-font-subtle-light dark:text-font-subtle-dark">—</span>')
-
-        status_lower = status.lower()
-
-        if any(word in status_lower for word in ['active', 'success', 'completed']):
-            variant = 'success'
-            icon_name = Icons.CHECK_CIRCLE
-        elif any(word in status_lower for word in ['pending', 'processing']):
-            variant = 'warning'
-            icon_name = Icons.WARNING
-        elif any(word in status_lower for word in ['failed', 'error', 'cancelled']):
-            variant = 'danger'
-            icon_name = Icons.ERROR
-        else:
-            variant = 'info'
-            icon_name = Icons.INFO
-
-        color_classes = {
-            'success': 'bg-green-100 text-green-800 dark:bg-green-900 dark:text-green-200',
-            'warning': 'bg-yellow-100 text-yellow-800 dark:bg-yellow-900 dark:text-yellow-200',
-            'danger': 'bg-red-100 text-red-800 dark:bg-red-900 dark:text-red-200',
-            'info': 'bg-blue-100 text-blue-800 dark:bg-blue-900 dark:text-blue-200',
-        }
-
-        color_class = color_classes.get(variant, color_classes['info'])
-
-        # Render icon with Material Icons
-        icon_html = format_html('<span class="material-symbols-outlined text-xs mr-1">{}</span>', icon_name)
-
-        return format_html(
-            '<span class="inline-flex items-center rounded-full px-2.5 py-0.5 text-xs font-medium {}">'
-            '{}{}'
-            '</span>',
-            color_class, icon_html, escape(status.replace('_', ' ').title())
-        )
-
-
 class DateTimeDisplay:
     """DateTime display utilities."""
 
