@@ -425,26 +425,61 @@ class UnfoldConfig(BaseModel):
             "show_all_applications": self.show_all_applications,
         }
 
-        # Get default navigation from dashboard manager first
-        nav_items = []
-        try:
-            from ..dashboard import DashboardManager
-            dashboard = DashboardManager()
-            nav_items = dashboard.get_navigation_config()
-        except Exception:
-            # Catch all exceptions including circular imports during settings generation
-            # During settings generation, config discovery may fail - use empty nav
-            pass
+        # Make navigation callable to defer URL resolution until Django is ready
+        def get_navigation(request=None):
+            """Generate navigation - called when Django is ready, not during settings init."""
+            nav_items = []
 
-        # Add custom navigation from project (if defined) - appears after default
-        if self.navigation:
-            nav_items.extend([group.to_dict() for group in self.navigation])
+            # Get default navigation from dashboard manager first
+            try:
+                from ..dashboard import DashboardManager
+                dashboard = DashboardManager()
+                nav_items = dashboard.get_navigation_config()
+            except Exception:
+                pass
 
-        # Add legacy navigation_items if configured
-        if self.navigation_items:
-            nav_items.extend(self.navigation_items)
+            # Add custom navigation from project (if defined) - appears after default
+            if self.navigation:
+                # Now it's safe to call to_dict() - Django URLs are ready
+                from django.urls import reverse
+                for group in self.navigation:
+                    # Convert NavigationSection to dict, resolving URL names
+                    group_dict = {
+                        "title": group.title,
+                        "separator": group.separator,
+                        "collapsible": group.collapsible,
+                        "items": []
+                    }
+                    if group.open:
+                        group_dict["open"] = True
 
-        sidebar_config["navigation"] = nav_items
+                    # Resolve each item's URL
+                    for item in group.items:
+                        item_link = item.link or "#"
+                        # Try to resolve URL names
+                        if not item_link.startswith(("/", "http", "#")):
+                            try:
+                                item_link = reverse(item_link)
+                            except Exception:
+                                pass  # Keep original if reverse fails
+
+                        group_dict["items"].append({
+                            "title": item.title,
+                            "icon": item.icon,
+                            "link": item_link,
+                            "badge": item.badge,
+                            "permission": item.permission,
+                        })
+
+                    nav_items.append(group_dict)
+
+            # Add legacy navigation_items if configured
+            if self.navigation_items:
+                nav_items.extend(self.navigation_items)
+
+            return nav_items
+
+        sidebar_config["navigation"] = get_navigation
         unfold_settings["SIDEBAR"] = sidebar_config
 
         # Add site dropdown - combine default from dashboard + project dropdown
