@@ -47,9 +47,7 @@ CORE_REGISTRY = {
 
     # Payment system models (BaseCfgAutoModule)
     "PaymentsConfig": ("django_cfg.models.payments.config", "PaymentsConfig"),
-    "ProviderAPIKeysConfig": ("django_cfg.models.payments.api_keys", "ProviderAPIKeysConfig"),
-    "BaseProviderConfig": ("django_cfg.models.payments.providers", "BaseProviderConfig"),
-    "NowPaymentsProviderConfig": ("django_cfg.models.payments.providers", "NowPaymentsProviderConfig"),
+    "NowPaymentsConfig": ("django_cfg.models.payments.config", "NowPaymentsConfig"),
 
     # Pagination classes
     "DefaultPagination": ("django_cfg.middleware.pagination", "DefaultPagination"),
