@@ -84,57 +84,23 @@ class SmartDefaults:
         ssl_redirect=None,
         cors_allow_headers=None
     ) -> Dict[str, Any]:
-        """Get security configuration defaults."""
-        from ..models.infrastructure.security import SecurityConfig
+        """
+        Get security configuration defaults.
 
-        # Base security settings
+        DEPRECATED: This method is kept for backward compatibility.
+        New code should use SecurityBuilder.build_security_settings() directly.
+
+        Note: This method now returns minimal settings. Full security configuration
+        is handled by SecurityBuilder which has Docker awareness and better logic.
+        """
+        # Base Django settings (non-security specific)
         base_settings = {
             'USE_TZ': True,
             'USE_I18N': True,
             'USE_L10N': True,
-            'SECURE_BROWSER_XSS_FILTER': not debug,
-            'SECURE_CONTENT_TYPE_NOSNIFF': not debug,
-            'X_FRAME_OPTIONS': 'DENY' if not debug else 'SAMEORIGIN',
-            'SECURE_HSTS_SECONDS': 31536000 if not debug else 0,
-            'SECURE_HSTS_INCLUDE_SUBDOMAINS': not debug,
-            'SECURE_HSTS_PRELOAD': not debug,
         }
 
-        # Add CORS settings if security domains are configured
-        if security_domains:
-            # Combine default CORS headers with custom ones
-            default_headers = SecurityConfig().cors_allow_headers
-            if cors_allow_headers:
-                # Combine and deduplicate headers
-                all_headers = default_headers + cors_allow_headers
-                seen = set()
-                unique_headers = []
-                for header in all_headers:
-                    if header.lower() not in seen:
-                        seen.add(header.lower())
-                        unique_headers.append(header)
-                final_headers = unique_headers
-            else:
-                final_headers = default_headers
-
-            # Create SecurityConfig with appropriate settings
-            security_config = SecurityConfig(
-                cors_enabled=True,
-                cors_allow_all_origins=debug or environment == "development",
-                cors_allowed_origins=security_domains if not (debug or environment == "development") else [],
-                cors_allow_credentials=True,
-                cors_allow_headers=final_headers,
-                ssl_redirect=ssl_redirect or False,
-            )
-
-            # Configure for development if needed
-            if debug or environment == "development":
-                security_config.configure_for_development()
-
-            # Get Django settings from SecurityConfig
-            cors_settings = security_config.to_django_settings()
-            base_settings.update(cors_settings)
-
+        # Return minimal settings - SecurityBuilder handles the rest
         return base_settings
 
     @classmethod
